@@ -10,7 +10,7 @@ package Finance::InteractiveBrokers::SWIG;
 use Data::Dumper;
 use Carp qw( croak confess longmess );
 use Socket qw( inet_ntoa inet_aton );
-use Net::hostent;
+use Net::hostent ();
 use strict;
 use warnings;
 
@@ -24,7 +24,7 @@ use Finance::InteractiveBrokers::SWIG::IBAPI;   # SWIG module
 
 use vars qw( $VERSION $AUTOLOAD $TRUE $FALSE $KEEP $DELETE $REQUIRED );
 BEGIN {
-    $VERSION  = '0.01_02';
+    $VERSION  = '0.03_03';
 }
 
 *TRUE     = \1;
@@ -155,7 +155,7 @@ sub api_methods
 
     # Version was valid, show the methods
     if( -t STDIN and -t STDOUT ) {
-        print "IB API methods callable for API version $version:\n";
+        print "InteractiveBrokers API methods callable for API version $version:\n";
         print "    $_\n" for( @methods );
     }
 
@@ -169,10 +169,10 @@ sub _resolve_host
     my $whatever = shift;
     my( $hostname, @addresses );
 
-    if( my $hent = gethostbyname( $whatever ) )
+    if( my $hent = Net::hostent::gethost( $whatever ) )
     {
         $hostname  = $hent->name;
-        @addresses = map { inet_ntoa( $_ ) } $hent->addr_list;
+        @addresses = map { inet_ntoa( $_ ) } @{ $hent->addr_list };
     }
 
     return( $hostname, @addresses );
@@ -300,13 +300,13 @@ Then:
     $ib->reqCurrentTime();
 
     # Your event loop here
-    $ib->processMessags()
+    $ib->processMessages()
         while( $ib->isConnected() );
 
     # And eventually...
     $ib->eDisconnect();
 
-See the C<examples/> directory in this distribution for more complete and
+See the F<examples/> directory in this distribution for more complete and
 well-commented examples.
 
 =head1 DESCRIPTION
@@ -354,10 +354,10 @@ Provides a programmatic means of looking up methods and events in the IB API.
 
 Capable of compiling C and C++ files, and running 'make'.
 
-=item * SWIG >= 1.3.36
+=item * SWIG >= 1.3.28
 
 The "Simplified Wrapper and Interface Generator", capable of building SWIG
-interfaces.  This module has been tested with SWIG versions 1.3.36 - 2.0.1.
+interfaces.  This module has been tested with SWIG versions 1.3.28 - 2.0.1.
 
 =back
 
@@ -391,7 +391,7 @@ L<Finance::InteractiveBrokers::SWIG::EventHandler>.  It is delegated to when
 receiving events from the IB service.
 
 Please see L<Finance::InteractiveBrokers::SWIG::EventHandler> for notes on
-how to subclass it, and the C<examples/> directory of this distribution.
+how to subclass it, and the F<examples/> directory of this distribution.
 
 B<RETURNS:> blessed C<$object>, or C<undef> on failure.
 
@@ -401,9 +401,9 @@ B<RETURNS:> blessed C<$object>, or C<undef> on failure.
 
 Initialize the object.  If you are subclassing, override this, not L</new()>.
 
-B<ARGUMENTS:> %HASH of arguments passed into L</new()>
+B<ARGUMENTS:> C<%HASH> of arguments passed into L</new()>
 
-B<RETURNS:> %HASH of any leftover arguments.
+B<RETURNS:> C<%HASH> of any leftover arguments.
 
 =head1 METHODS
 
@@ -421,7 +421,7 @@ find actual C<sub> definitions for them in the source.
 
 B<ARGUMENTS:> None.
 
-B<RETURNS:> @ARRAY of callable IB API methods.
+B<RETURNS:> C<@ARRAY> of callable IB API methods.
 
 B<NOTE:> You can also get a list of them from the command line, via:
 
@@ -430,8 +430,8 @@ B<NOTE:> You can also get a list of them from the command line, via:
 =head2 eConnect()
 
 Small wrapper around the IB API eConnect() call to add DNS resolution.
-See the L</"INTERACTIVE BROKERS API"> section for full information how
-to use the IB API.
+See L</"INTERACTIVE BROKERS API"> for full information on how to use the
+IB API.
 
 =head2 api_version()
 
@@ -439,7 +439,8 @@ to use the IB API.
 
 Get the IB API version this module was compiled against.
 
-B<RETURNS:> $scalar containing the version as a string, something like '9.64'.
+B<RETURNS:> C<$scalar> containing the version as a string, something like
+C<'9.64'>.
 
 =head1 INTERACTIVE BROKERS API
 
@@ -469,7 +470,7 @@ L<http://www.interactivebrokers.com/> - The InteractiveBrokers website
 
 L<http://www.interactivebrokers.com/php/apiUsersGuide/apiguide.htm> - The IB API documentation
 
-The examples/ directory of this module's distribution.
+The F<examples/> directory of this module's distribution.
 
 =head1 AUTHORS
 
@@ -482,6 +483,22 @@ C<bug-finance-interactivebrokers-swig at rt.cpan.org>, or through
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Finance-InteractiveBrokers-SWIG>.  The authors will be notified, and then you'll
 automatically be notified of progress on your bug as changes are made.
 
+If you are sending a bug report, please include:
+
+=over 4
+
+=item * Your OS type, version, Perl version, and other similar information.
+
+=item * The version of Finance::InteractiveBrokers::SWIG you are using.
+
+=item * The version of the InteractiveBrokers API you are using.
+
+=item * If possible, a minimal test script which demonstrates your problem.
+
+=back
+
+This will be of great assistance in troubleshooting your issue.
+
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
