@@ -22,7 +22,7 @@ use Finance::InteractiveBrokers::SWIG::IBAPI;
 
 use vars qw( $VERSION $TRUE $FALSE $KEEP $DELETE $REQUIRED $AUTOLOAD );
 BEGIN {
-    $VERSION   = '0.01_02';
+    $VERSION   = '0.03_03';
 }
 
 *TRUE      = \1;
@@ -207,7 +207,7 @@ into a database, analyze, etc).
 An object of your subclass should be instantiated, and passed in as an
 argument to L<Finance::InteractiveBrokers::SWIG/"new">.
 
-There is a well-commented example subclass in the C<examples/> directory of
+There is a well-commented example subclass in the F<examples/> directory of
 this module's distribution, on which you must base your subclass.
 
 =head1 CONSTRUCTOR
@@ -227,9 +227,9 @@ B<RETURNS:> blessed C<$object>, or C<undef> on failure.
 Initialize the object.  When subclassing, override this (if desired),
 not L</new()>.
 
-B<ARGUMENTS:> %HASH of arguments passed into L</new()>
+B<ARGUMENTS:> C<%HASH> of arguments passed into L</new()>
 
-B<RETURNS:> %HASH of any leftover arguments.
+B<RETURNS:> C<%HASH> of any leftover arguments.
 
 =head1 METHODS
 
@@ -248,7 +248,7 @@ so you will not find C<sub> definitions in the source.
 
 B<ARGUMENTS:> None.
 
-B<RETURNS:> @ARRAY of IB API events that must be overridden.
+B<RETURNS:> C<@ARRAY> of IB API events that must be overridden.
 
 B<NOTE:> You can also get a list of them from the command line, via:
 
@@ -260,7 +260,7 @@ B<NOTE:> You can also get a list of them from the command line, via:
 
 Get the IB API version this module was compiled against.
 
-B<RETURNS:> $scalar containing the version as a string, something like '9.64'.
+B<RETURNS:> C<$scalar> containing the version as a string, something like '9.64'.
 
 =head1 THE INTERACTIVE BROKERS API
 
@@ -290,7 +290,7 @@ L<http://www.interactivebrokers.com/> - The InteractiveBrokers website
 
 L<http://www.interactivebrokers.com/php/apiUsersGuide/apiguide.htm> - The IB API documentation
 
-The examples/ directory of this module's distribution
+The F<examples/> directory of this module's distribution
 
 =head1 AUTHORS
 
@@ -303,6 +303,22 @@ C<bug-finance-interactivebrokers-swig at rt.cpan.org>, or through
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Finance-InteractiveBrokers-SWIG>.  The authors will be notified, and then you'll
 automatically be notified of progress on your bug as changes are made.
 
+If you are sending a bug report, please include:
+
+=over 4
+
+=item * Your OS type, version, Perl version, and other similar information.
+
+=item * The version of Finance::InteractiveBrokers::SWIG you are using.
+
+=item * The version of the InteractiveBrokers API you are using.
+
+=item * If possible, a minimal test script which demonstrates your problem.
+
+=back
+
+This will be of great assistance in troubleshooting your issue.
+
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
